==> matrix-react-sdk-3.63.0.tgz: package/src/components/views/toasts/NonUrgentEchoFailureToast.tsx <==
/*
Copyright 2020 The Matrix.org Foundation C.I.C.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import React from "react";

import { _t } from "../../../languageHandler";
import AccessibleButton from "../elements/AccessibleButton";
import Modal from "../../../Modal";
import ServerOfflineDialog from "../dialogs/ServerOfflineDialog";

export default class NonUrgentEchoFailureToast extends React.PureComponent {
    private openDialog = () => {
        Modal.createDialog(ServerOfflineDialog, {});
    };

    public render() {
        return (
            <div className="mx_NonUrgentEchoFailureToast">
                <span className="mx_NonUrgentEchoFailureToast_icon" />
                {_t(
                    "Your server isn't responding to some <a>requests</a>.",
                    {},
                    {
                        a: (sub) => (
                            <AccessibleButton kind="link_inline" onClick={this.openDialog}>
                                {sub}
                            </AccessibleButton>
                        ),
                    },
                )}
            </div>
        );
    }
}

==> matrix-react-sdk-3.84.0.tgz: package/src/components/views/toasts/NonUrgentEchoFailureToast.tsx <==
/*
Copyright 2020 The Matrix.org Foundation C.I.C.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import React from "react";

import { _t } from "../../../languageHandler";
import AccessibleButton from "../elements/AccessibleButton";
import Modal from "../../../Modal";
import ServerOfflineDialog from "../dialogs/ServerOfflineDialog";

export default class NonUrgentEchoFailureToast extends React.PureComponent {
    private openDialog = (): void => {
        Modal.createDialog(ServerOfflineDialog, {});
    };

    public render(): React.ReactNode {
        return (
            <div className="mx_NonUrgentEchoFailureToast">
                <span className="mx_NonUrgentEchoFailureToast_icon" />
                {_t(
                    "error|non_urgent_echo_failure_toast",
                    {},
                    {
                        a: (sub) => (
                            <AccessibleButton kind="link_inline" onClick={this.openDialog}>
                                {sub}
                            </AccessibleButton>
                        ),
                    },
                )}
            </div>
        );
    }
}
